@@ -1,5 +1,5 @@
 package Test::Subs;
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 use strict;
 use warnings;
 use feature 'switch';
@@ -13,7 +13,7 @@ use List::MoreUtils 'any';
 
 
 our @EXPORT = ('test', 'todo', 'not_ok', 'match', 'fail', 'failwith', 'comment',
-		'debug', 'test_pod'
+		'debug', 'test_pod', 'skip'
 	);
 
 my (@tests, @todo, @comments,@pods);
@@ -243,6 +243,21 @@ sub print_res {
 	printf STDOUT "%sok %d%s\n",  ($ok ? '' : 'not '), ++$count, $m;
 }
 
+sub skip {
+	my ($reason) = @_;
+	&check_run;
+	
+	if ($reason) {
+		print STDOUT "1..0 # skip $reason\n";
+	} else {
+		print STDOUT "1..0\n";
+	}
+	
+	$has_run = 1;
+
+	exit 0;
+}
+
 sub run_test {
 	$is_running = 1;
 
@@ -445,12 +460,24 @@ error handle. The buffering on C<STDOUT> and C<STDERR> is deactivated when
 C<Test::Subs> is used and the output of this function should appear in between
 the result of the test when the test file is run stand-alone.
 
-This function must be used outside of the code the other functions described
-above. The output comment to C<STDERR> inside a test, just use the C<print> or
+This function must be used outside of the code of the other functions described
+above. To output comment to C<STDERR> inside a test, just use the C<print> or
 C<printf> function. The default output has been C<select>-ed to C<STDERR> so
 the result of the test will not be altered.
 
-=head2 test_pod
+=head2 skip (new in 0.07)
+
+  skip 'reason' unless eval { use Foo::Bar };
+
+This function allows to skip a test file. It must be used outside of test subs
+of the other functions. You will typically use it to disable a test file if the
+current version of Perl is missing some required functionnalities for the tests.
+
+The argument for the function is a string explaining the reason why the tests
+have been skipped. This reasion will be reported in the output of a C<Test::Harness>
+run.
+
+=head2 test_pod (new in 0.04)
 
   test_pod(LIST);
 
@@ -471,7 +498,7 @@ Usefull when a test fail to quickly see what is going on.
 
 =head1 OPTIONS
 
-=head2 Debug mode
+=head2 Debug mode (new in 0.03)
 
 You can pass a C<debug> argument to the package when you are C<using> it:
 
@@ -482,7 +509,7 @@ functions will behave like calls to the C<debug> function. Also, most of the
 function of this library will give more output (on C<STDERR>) if their test
 fails.
 
-=head2 Path to the library files
+=head2 Path to the library files (new in 0.05)
 
 By default, if you specify a C<'My::Module'> module as a target of the C<test_pod>
 function, the file for this module will be searched in C<lib/My/Module.pm>
@@ -496,7 +523,7 @@ The supplied path will serve as the base directory to look for the module file
 (e.g. C<My/Module.pm>), B<relatively to the the test script directory> (and not
 to the current working directory as in the default case).
 
-=head2 Warning level for POD Checking
+=head2 Warning level for POD Checking (new in 0.05)
 
 You can tune the number of warning generated by the C<test_pod> function using
 a C<pod_warn> argument to the package when you are C<using> it:
@@ -564,7 +591,7 @@ Mathias Kende (mathias@cpan.org)
 
 =head1 VERSION
 
-Version 0.06 (February 2013)
+Version 0.07 (February 2013)
 
 =head1 COPYRIGHT & LICENSE
 
